==> haskell-concurrent-output-1.10.7-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.7
id: concurrent-output-1.10.7-HQNSPVHOIo39dfBw2Lo8KE
key: concurrent-output-1.10.7-HQNSPVHOIo39dfBw2Lo8KE
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: ffcbe6359a58c2250084340ea9f8f5e1
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.4.3/site-local/concurrent-output-1.10.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/concurrent-output-1.10.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/concurrent-output-1.10.7
hs-libraries: HSconcurrent-output-1.10.7-HQNSPVHOIo39dfBw2Lo8KE
depends:
    base-4.11.1.0 text-1.2.3.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    stm-2.4.5.0 process-1.6.3.0 directory-1.3.1.5 transformers-0.5.5.0
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
    ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6
    terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y unix-2.7.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6=892601395148dacdd997061542e42ef5
             terminal-size-0.3.2.1-KN6K6Ef1GMWIEqS2qb6D5y=9e8f4161238e0158818b6fad8eeb5556
             unix-2.7.2.2=5200b6eb79607eed6537538f20d679bf
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.10.7-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.7
id: concurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
key: concurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: d992a7ec2bf57c1656e24f9401c2df83
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
library-dirs: /usr/lib/ghc-8.6.1/site-local/concurrent-output-1.10.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/concurrent-output-1.10.7
hs-libraries: HSconcurrent-output-1.10.7-5q2XjljoItQBGceSoG4Vpi
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 directory-1.3.3.0
    exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1 process-1.6.3.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY
    text-1.2.3.1 transformers-0.5.5.0 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
